pub struct Padding { /* private fields */ }Expand description
Padding is responsible for a left/right/top/bottom inner indent of a particular cell.
Example
use tabled::{
Table,
settings::{Padding, Style, Modify, object::Cell},
};
let table = Table::new("2022".chars())
.with(Style::modern())
.with(Modify::new((2, 0)).with(Padding::new(1, 1, 2, 2)))
.to_string();
assert_eq!(
table,
concat!(
"┌──────┐\n",
"│ char │\n",
"├──────┤\n",
"│ 2 │\n",
"├──────┤\n",
"│ │\n",
"│ │\n",
"│ 0 │\n",
"│ │\n",
"│ │\n",
"├──────┤\n",
"│ 2 │\n",
"├──────┤\n",
"│ 2 │\n",
"└──────┘",
),
);Implementations
Sourceimpl Padding
impl Padding
Sourcepub const fn new(
left: usize,
right: usize,
top: usize,
bottom: usize,
) -> Padding
pub const fn new( left: usize, right: usize, top: usize, bottom: usize, ) -> Padding
Construct’s an Padding object.
It uses space(’ ’) as a default fill character.
To set a custom character you can use Padding::fill function.
Sourcepub const fn zero() -> Padding
pub const fn zero() -> Padding
Construct’s an Padding object with all sides set to 0.
It uses space(’ ’) as a default fill character.
To set a custom character you can use Padding::fill function.
Sourcepub const fn fill(
self,
left: char,
right: char,
top: char,
bottom: char,
) -> Padding
pub const fn fill( self, left: char, right: char, top: char, bottom: char, ) -> Padding
The function, sets a characters for the padding on an each side.
Sourcepub const fn expand(horizontal: bool) -> PaddingExpand
pub const fn expand(horizontal: bool) -> PaddingExpand
Construct’s an PaddingExpand object.